package ink.wgink.code.factory.factory;

import ink.wgink.code.factory.enums.FormFieldTypeEnum;
import ink.wgink.code.factory.vos.FieldVO;
import javafx.beans.property.ReadOnlyObjectWrapper;
import javafx.beans.value.ObservableValue;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.scene.control.ChoiceBox;
import javafx.scene.control.TableColumn;
import javafx.util.Callback;
import org.apache.commons.lang3.StringUtils;

import java.text.Normalizer;

/**
 * When you feel like quitting. Think about why you started
 * 当你想要放弃的时候，想想当初你为何开始
 *
 * @ClassName: SelectTableCellFactory
 * @Description: 表格下拉列表
 * @Author: WangGeng
 * @Date: 2021/3/7 10:52
 * @Version: 1.0
 **/
public class ChoiceBoxTableCellFactory implements Callback<TableColumn.CellDataFeatures<FieldVO, String>, ObservableValue<ChoiceBox<String>>> {

    private final String property;
    private ObservableList<String> normalSelect = FXCollections.observableArrayList(
            "", FormFieldTypeEnum.TEXT.getValue(), FormFieldTypeEnum.NUMBER.getValue(),
            FormFieldTypeEnum.DOUBLE.getValue(), FormFieldTypeEnum.TEXTAREA.getValue(),
            FormFieldTypeEnum.SELECT_USER.getValue(), FormFieldTypeEnum.SELECT_DEPARTMENT.getValue(),
            FormFieldTypeEnum.FILE.getValue(), FormFieldTypeEnum.IMAGE.getValue(),
            FormFieldTypeEnum.AUDIO.getValue(), FormFieldTypeEnum.VIDEO.getValue(),
            FormFieldTypeEnum.CHECKBOX.getValue()
    );
    private ObservableList<String> singleSelect = FXCollections.observableArrayList(
            "",
            FormFieldTypeEnum.RADIO.getValue(),
            FormFieldTypeEnum.SELECT.getValue()
    );

    public ChoiceBoxTableCellFactory(String property) {
        this.property = property;
    }

    @Override
    public ObservableValue<ChoiceBox<String>> call(TableColumn.CellDataFeatures<FieldVO, String> param) {
        ChoiceBox choiceBox = new ChoiceBox();
        choiceBox.setPrefWidth(150);
        if (StringUtils.equalsIgnoreCase(FormFieldTypeEnum.ID_SELECT.getValue(), param.getValue().getFormFieldType())) {
            choiceBox.setItems(singleSelect);
        } else {
            choiceBox.setItems(normalSelect);
        }
        choiceBox.getSelectionModel().select(param.getValue().getFormFieldType());
        return new ReadOnlyObjectWrapper<>(choiceBox);
    }
}
